application_action — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- admin »
- action »

# application_action

class `camelot.admin.action.application_action.` `ApplicationActionGuiContext`

  The GUI context for an `camelot.admin.action.Action`. On top of the attributes of the `camelot.admin.action.base.GuiContext`, this context contains :

  `workspace`

    the the `camelot.view.workspace.DesktopWorkspace` of the application in which views can be opened or adapted.

  `admin`

    the application admin.

  `model_context`

    alias of `ApplicationActionModelContext`

class `camelot.admin.action.application_action.` `ApplicationActionModelContext`

  The Model context for an `camelot.admin.action.Action`. On top of the attributes of the `camelot.admin.action.base.ModelContext`, this context contains :

  `admin`

    the application admin.

class `camelot.admin.action.application_action.` `EntityAction`(entity_admin)

  Generic ApplicationAction that acts upon an Entity class

class `camelot.admin.action.application_action.` `OpenNewView`(entity_admin)

  An application action that opens a new view of an Entity

  Parameters: | entity_admin – an instance of `camelot.admin.entity_admin.EntityAdmin` to be used to visualize the entities

  `gui_run`(gui_context)

    Returns: | a new view

class `camelot.admin.action.application_action.` `OpenTableView`(entity_admin)

  An application action that opens a TableView of an Entity

  Parameters: | entity_admin – an instance of `camelot.admin.entity_admin.EntityAdmin` to be used to visualize the entities

class `camelot.admin.action.application_action.` `ShowHelp`

  Display the help window

`camelot.admin.action.application_action.` `structure_to_application_action`(structure, application_admin)

  Convert a python structure to an ApplicationAction

  Parameters: | application_admin – the `camelot.admin.application_admin.ApplicationAdmin` to use to create other Admin classes.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- admin »
- action »

Comments
blog comments powered by Disqus